
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef ndd_POSTER_LIB_H
#define ndd_POSTER_LIB_H

#include "posterLib.h"
#include "genom/genom.h"

/* Types definis ou utilises par le module */
#include "nddType.h"
#include "nddError.h"

/* 
 * Definition de la SDI_C 
*/
typedef struct {
  CNTRL_TASK_DESCRIPTION cntrlTask;
  EXEC_TASK_DESCRIPTION execTaskTab[NDD_NB_EXEC_TASK];
  ACTIVITY_DESCRIPTION activityTab[MAX_ACTIVITIES];
} NDD_CNTRL_STR;

/* For consistency with other posters */
typedef NDD_CNTRL_STR NDD_CNTRL_POSTER_STR;
 
/* 
 * Definition des structures de posters
 */
#include "nddPosterLibStruct.h"



/* Posters */
#define NDD_CNTRL_POSTER_NAME genomInstanceSuffixName("ndd", "Cntrl")
#define NDD_REF_POSTER_NAME genomInstanceSuffixName("ndd", "Ref")
#define NDD_GOAL_POSTER_NAME genomInstanceSuffixName("ndd", "Goal")
#define NDD_DIAGRAM_POSTER_NAME genomInstanceSuffixName("ndd", "Diagram")
#define NDD_PARAMS_POSTER_NAME genomInstanceSuffixName("ndd", "Params")
#define NDD_MAXSPEED_POSTER_NAME genomInstanceSuffixName("ndd", "MaxSpeed")


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif
extern STATUS nddPosterInit ( void );
extern POSTER_ID nddCntrlPosterID ();
extern STATUS nddCntrlPosterRead ( NDD_CNTRL_STR *nddCntrlStrId );
extern STATUS nddCntrlPosterInit ( void );
extern STATUS nddCntrlInstancePosterRead(const char *name, NDD_CNTRL_STR *nddCntrlStrId);
extern STATUS nddRefPosterInit ( void );
extern POSTER_ID nddRefPosterID ( void );
extern STATUS nddRefPosterRead ( NDD_REF_POSTER_STR *x );
extern STATUS nddRefInstancePosterRead ( const char *, NDD_REF_POSTER_STR * );
extern STATUS nddRefspeedRefPosterRead ( GENPOS_CART_SPEED *speedRef );
extern STATUS nddRefspeedRefInstancePosterRead( const char *, GENPOS_CART_SPEED * );
extern STATUS nddGoalPosterInit ( void );
extern POSTER_ID nddGoalPosterID ( void );
extern STATUS nddGoalPosterRead ( NDD_GOAL_POSTER_STR *x );
extern STATUS nddGoalInstancePosterRead ( const char *, NDD_GOAL_POSTER_STR * );
extern STATUS nddGoalglobal_goalPosterRead ( GENPOS_CART_CONFIG *global_goal );
extern STATUS nddGoalglobal_goalInstancePosterRead( const char *, GENPOS_CART_CONFIG * );
extern STATUS nddGoallocal_goalPosterRead ( GENPOS_CART_CONFIG *local_goal );
extern STATUS nddGoallocal_goalInstancePosterRead( const char *, GENPOS_CART_CONFIG * );
extern STATUS nddGoalmotionChoicePosterRead ( NDD_CHOICE *motionChoice );
extern STATUS nddGoalmotionChoiceInstancePosterRead( const char *, NDD_CHOICE * );
extern STATUS nddGoalnextToVisitPosterRead ( int *nextToVisit );
extern STATUS nddGoalnextToVisitInstancePosterRead( const char *, int * );
extern STATUS nddGoalunusedPosterRead ( int *unused );
extern STATUS nddGoalunusedInstancePosterRead( const char *, int * );
extern STATUS nddDiagramPosterInit ( void );
extern POSTER_ID nddDiagramPosterID ( void );
extern STATUS nddDiagramPosterRead ( NDD_DIAGRAM_POSTER_STR *x );
extern STATUS nddDiagramInstancePosterRead ( const char *, NDD_DIAGRAM_POSTER_STR * );
extern STATUS nddDiagramnddDiagramPosterPosterRead ( NDD_DIAGRAM *nddDiagramPoster );
extern STATUS nddDiagramnddDiagramPosterInstancePosterRead( const char *, NDD_DIAGRAM * );
extern STATUS nddParamsPosterInit ( void );
extern POSTER_ID nddParamsPosterID ( void );
extern STATUS nddParamsPosterRead ( NDD_PARAMS_POSTER_STR *x );
extern STATUS nddParamsInstancePosterRead ( const char *, NDD_PARAMS_POSTER_STR * );
extern STATUS nddParamsParamsPosterRead ( NDD_PARAMS *Params );
extern STATUS nddParamsParamsInstancePosterRead( const char *, NDD_PARAMS * );
extern STATUS nddMaxSpeedPosterInit ( void );
extern POSTER_ID nddMaxSpeedPosterID ( void );
extern STATUS nddMaxSpeedPosterRead ( NDD_MAXSPEED_POSTER_STR *x );
extern STATUS nddMaxSpeedInstancePosterRead ( const char *, NDD_MAXSPEED_POSTER_STR * );
extern STATUS nddMaxSpeedMaxSpeedPosterRead ( NDD_SPEED *MaxSpeed );
extern STATUS nddMaxSpeedMaxSpeedInstancePosterRead( const char *, NDD_SPEED * );
#ifdef __cplusplus
}
#endif
#endif

